SUPPORTED_FORMATS
Built-in mutable sequence.
SUPPORTED_FORMATS: list[str] = ["json", "csv", "xml"]
If no argument is given, the constructor creates a new empty list. The argument must be an iterable if specified.
Built-in mutable sequence.
SUPPORTED_FORMATS: list[str] = ["json", "csv", "xml"]
If no argument is given, the constructor creates a new empty list. The argument must be an iterable if specified.